==> pitaya-framework-0.0.2.tgz: package/src/utils.ts <==
import { IValidatable } from "../index";

const _GUID_PREFIX: string = "pitaya-";
let _idCounter: number     = 0;

export const NOOP = function(){};

export const wait = function( ms: number )
{
	return new Promise( ( resolve ) => window.setTimeout( resolve, ms ) );
};

export const delay = function( ms: number )
{
	return new Promise( ( resolve ) => window.setTimeout( resolve, ms ) );
};

export const nextAnimationFrame = function()
{
	return new Promise( ( resolve ) => requestAnimationFrame( resolve ) );
};

export const nextEventRaise = function( element: HTMLElement, eventName: string ): Promise<void>
{
	return new Promise( ( resolve ) =>
	{
		const callback = ( event: Event ) =>
		{
			if( event.srcElement !== element )
			{
				return;
			}

			element.removeEventListener( eventName, callback );

			resolve();
		};

		element.addEventListener( eventName, callback );
	} );
};

export const createElement = function( htmlString: string ): Node
{
	const template = document.createElement( "template" ) as HTMLElement;

	template.innerHTML = htmlString.trim();

	return template[ "content" ].firstChild;
};

export const validateComponents = function( components: IValidatable[] ): boolean
{
	let valid = true;

	for( const component of components )
	{
		if( !component.validate() )
		{
			valid = false;
		}
	}

	return valid;
};

export const getJSON = async ( url ) =>
{
	const response = await fetch( url );
	const status   = response.status;

	if( status >= 200 && status < 300 )
	{
		return response.json();
	}
	else
	{
		// throw the object you desire which you will handle
		// in this case the json error response might give us
		// a json body so we can use that.
		throw {
			status : status,
			body   : await response.json()
		};
		// or throw an error
		// throw Error(await response.statusText)
	}
};

export const generateGUID = function(): string
{
	return `${_GUID_PREFIX}${_idCounter++}`;
}

==> pitaya-framework-0.0.3.tgz: package/src/utils.ts <==
import { IValidatable } from "../interfaces.d";

const _GUID_PREFIX: string = "pitaya-";
let _idCounter: number     = 0;

export const NOOP = function(){};

export const delay = function( ms: number )
{
	return new Promise( ( resolve ) => window.setTimeout( resolve, ms ) );
};

export const nextAnimationFrame = function()
{
	return new Promise( ( resolve ) => requestAnimationFrame( resolve ) );
};

export const nextEventRaise = function( element: HTMLElement, eventName: string ): Promise<void>
{
	return new Promise( ( resolve ) =>
	{
		const callback = ( event: Event ) =>
		{
			if( event.srcElement !== element )
			{
				return;
			}

			element.removeEventListener( eventName, callback );

			resolve();
		};

		element.addEventListener( eventName, callback );
	} );
};

export const createElement = function( htmlString: string ): Node
{
	const template = document.createElement( "template" ) as HTMLElement;

	template.innerHTML = htmlString.trim();

	return template[ "content" ].firstChild;
};

export const validateComponents = function( components: IValidatable[] ): boolean
{
	let valid = true;

	for( const component of components )
	{
		if( !component.validate() )
		{
			valid = false;
		}
	}

	return valid;
};

export const getJSON = async ( url: string ) =>
{
	const response = await fetch( url );
	const status   = response.status;

	if( status >= 200 && status < 300 )
	{
		return response.json();
	}
	else
	{
		// throw the object you desire which you will handle
		// in this case the json error response might give us
		// a json body so we can use that.
		throw {
			status,
			body : await response.json()
		};
		// or throw an error
		// throw Error(await response.statusText)
	}
};

export const generateGUID = function(): string
{
	return `${_GUID_PREFIX}${_idCounter++}`;
};
